# Problem with RC oscillator and bootloader

### Problem situation one:

Description:

When using the `CONFIG_CLOCK_CONTROL_NRF_K32SRC_RC=y` option in the application and not setting it in the bootloader will result in a application hang when `usb_enable(NULL);` is called.

The problem does not occur when `CONFIG_CLOCK_CONTROL_NRF_K32SRC_RC=y` is set in the bootloader. 

Exepected behaviour:

- Log on the segger rtt console with the bootloader info.
- Blinky led every second 
- Log over the NRF usb connection (not the segger rtt console)

How to reproduce: 

Unzip the provided files and put them where you can use them with Zephyr.

not working
```
west build -p -b nrf52840dk_nrf52840 -- -DDTC_OVERLAY_FILE=console.overlay && west flash
```

working
```
west build -p -b nrf52840dk_nrf52840 -- -DDTC_OVERLAY_FILE=console.overlay -Dmcuboot_OVERLAY_CONFIG=$(realpath mcuboot.conf) && west flash
```
### Problem situation two: 

Description:

When using `MPSL` "DRGN-6362: The synthesized low frequency clock source is neither tested nor intended for usage with MPSL." 
So this results selecting `CONFIG_CLOCK_CONTROL_NRF_K32SRC_RC=y` due to having no low frequency crystal on our board. When the RC oscillator is selected also `CONFIG_CLOCK_CONTROL_NRF_CALIBRATION_MAX_SKIP=0` needs to be selected. When this is selected and also used in the bootloader the application will hang (infinite loop) when:

- calling usb_enable();
- enabling BLE;
- enabling IEEE802.15.4.

This can be "fixed" by selecting the synthesized low frequency clock but that is not supported for MPSL. 

As this seems to be a bug in the clock system and we already have products shipped without the `CONFIG_CLOCK_CONTROL_NRF_K32SRC_RC=y` symbol enabled in the bootloader. We are looking for a way to use `CONFIG_CLOCK_CONTROL_NRF_K32SRC_RC=y` in the application without it locking up as we want to upgrade to NCS v1.8.0 from 1.5.1.

Expected behaviour:
- Log on the segger rtt console with the bootloader info.
- Blinky led every second 
- Log over the NRF usb connection (not the segger rtt console)

How to reproduce: 

Unzip the provided files and put them where you can use them with Zephyr.

not working
```
west build -p -b nrf52840dk_nrf52840 -- -DDTC_OVERLAY_FILE=console.overlay -DOVERLAY_CONFIG=radio.conf -Dmcuboot_OVERLAY_CONFIG=$(realpath mcuboot.conf)-DPICOO_RADIO=ON && west flash
```
